package com.xxl.job.admin.controller;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.xxl.job.admin.controller.annotation.PermissionLimit;
import com.xxl.job.admin.core.model.XxlJobGroup;
import com.xxl.job.admin.core.model.XxlJobRegistry;
import com.xxl.job.admin.core.util.I18nUtil;
import com.xxl.job.admin.dao.XxlJobGroupDao;
import com.xxl.job.admin.dao.XxlJobInfoDao;
import com.xxl.job.admin.dao.XxlJobRegistryDao;
import com.xxl.job.core.biz.model.ReturnT;
import com.xxl.job.core.enums.RegistryConfig;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

@Controller
@RequestMapping({"/jobgroup"})
public class JobGroupController {
  @Resource
  public XxlJobInfoDao xxlJobInfoDao;
  
  @Resource
  public XxlJobGroupDao xxlJobGroupDao;
  
  @Resource
  private XxlJobRegistryDao xxlJobRegistryDao;
  
  @RequestMapping
  @PermissionLimit(adminuser = true)
  public String index(Model model) {
    return "jobgroup/jobgroup.index";
  }
  
  @RequestMapping({"/pageList"})
  @ResponseBody
  @PermissionLimit(adminuser = true)
  public Map<String, Object> pageList(HttpServletRequest request, @RequestParam(required = false, defaultValue = "0") int start, @RequestParam(required = false, defaultValue = "10") int length, String appname, String title) {
    List<XxlJobGroup> list = this.xxlJobGroupDao.pageList(start, length, appname, title);
    int list_count = this.xxlJobGroupDao.pageListCount(start, length, appname, title);
    Map<String, Object> maps = new HashMap<>();
    maps.put("recordsTotal", Integer.valueOf(list_count));
    maps.put("recordsFiltered", Integer.valueOf(list_count));
    maps.put("data", list);
    return maps;
  }
  
  @RequestMapping({"/save"})
  @ResponseBody
  @PermissionLimit(adminuser = true)
  public ReturnT<String> save(XxlJobGroup xxlJobGroup) {
    if (xxlJobGroup.getAppname() == null || xxlJobGroup.getAppname().trim().length() == 0)
      return new ReturnT(500, I18nUtil.getString("system_please_input") + "AppName"); 
    if (xxlJobGroup.getAppname().length() < 4 || xxlJobGroup.getAppname().length() > 64)
      return new ReturnT(500, I18nUtil.getString("jobgroup_field_appname_length")); 
    if (xxlJobGroup.getAppname().contains(">") || xxlJobGroup.getAppname().contains("<"))
      return new ReturnT(500, "AppName" + I18nUtil.getString("system_unvalid")); 
    if (xxlJobGroup.getTitle() == null || xxlJobGroup.getTitle().trim().length() == 0)
      return new ReturnT(500, I18nUtil.getString("system_please_input") + I18nUtil.getString("jobgroup_field_title")); 
    if (xxlJobGroup.getTitle().contains(">") || xxlJobGroup.getTitle().contains("<"))
      return new ReturnT(500, I18nUtil.getString("jobgroup_field_title") + I18nUtil.getString("system_unvalid")); 
    if (xxlJobGroup.getAddressType() != 0) {
      if (xxlJobGroup.getAddressList() == null || xxlJobGroup.getAddressList().trim().length() == 0)
        return new ReturnT(500, I18nUtil.getString("jobgroup_field_addressType_limit")); 
      if (xxlJobGroup.getAddressList().contains(">") || xxlJobGroup.getAddressList().contains("<"))
        return new ReturnT(500, I18nUtil.getString("jobgroup_field_registryList") + I18nUtil.getString("system_unvalid")); 
      String[] addresss = xxlJobGroup.getAddressList().split(",");
      for (String item : addresss) {
        if (item == null || item.trim().length() == 0)
          return new ReturnT(500, I18nUtil.getString("jobgroup_field_registryList_unvalid")); 
      } 
    } 
    xxlJobGroup.setUpdateTime(new Date());
    int ret = this.xxlJobGroupDao.save(xxlJobGroup);
    return (ret > 0) ? ReturnT.SUCCESS : ReturnT.FAIL;
  }
  
  @RequestMapping({"/update"})
  @ResponseBody
  @PermissionLimit(adminuser = true)
  public ReturnT<String> update(XxlJobGroup xxlJobGroup) {
    if (xxlJobGroup.getAppname() == null || xxlJobGroup.getAppname().trim().length() == 0)
      return new ReturnT(500, I18nUtil.getString("system_please_input") + "AppName"); 
    if (xxlJobGroup.getAppname().length() < 4 || xxlJobGroup.getAppname().length() > 64)
      return new ReturnT(500, I18nUtil.getString("jobgroup_field_appname_length")); 
    if (xxlJobGroup.getTitle() == null || xxlJobGroup.getTitle().trim().length() == 0)
      return new ReturnT(500, I18nUtil.getString("system_please_input") + I18nUtil.getString("jobgroup_field_title")); 
    if (xxlJobGroup.getAddressType() == 0) {
      List<String> registryList = findRegistryByAppName(xxlJobGroup.getAppname());
      String addressListStr = null;
      if (registryList != null && !registryList.isEmpty()) {
        Collections.sort(registryList);
        addressListStr = "";
        for (String item : registryList)
          addressListStr = addressListStr + item + ","; 
        addressListStr = addressListStr.substring(0, addressListStr.length() - 1);
      } 
      xxlJobGroup.setAddressList(addressListStr);
    } else {
      if (xxlJobGroup.getAddressList() == null || xxlJobGroup.getAddressList().trim().length() == 0)
        return new ReturnT(500, I18nUtil.getString("jobgroup_field_addressType_limit")); 
      String[] addresss = xxlJobGroup.getAddressList().split(",");
      for (String item : addresss) {
        if (item == null || item.trim().length() == 0)
          return new ReturnT(500, I18nUtil.getString("jobgroup_field_registryList_unvalid")); 
      } 
    } 
    xxlJobGroup.setUpdateTime(new Date());
    int ret = this.xxlJobGroupDao.update(xxlJobGroup);
    return (ret > 0) ? ReturnT.SUCCESS : ReturnT.FAIL;
  }
  
  private List<String> findRegistryByAppName(String appnameParam) {
    HashMap<String, List<String>> appAddressMap = new HashMap<>();
    List<XxlJobRegistry> list = this.xxlJobRegistryDao.findAll(90, new Date());
    if (list != null)
      for (XxlJobRegistry item : list) {
        if (RegistryConfig.RegistType.EXECUTOR.name().equals(item.getRegistryGroup())) {
          String appname = item.getRegistryKey();
          List<String> registryList = appAddressMap.get(appname);
          if (registryList == null)
            registryList = new ArrayList<>(); 
          if (!registryList.contains(item.getRegistryValue()))
            registryList.add(item.getRegistryValue()); 
          appAddressMap.put(appname, registryList);
        } 
      }  
    return appAddressMap.get(appnameParam);
  }
  
  @RequestMapping({"/remove"})
  @ResponseBody
  @PermissionLimit(adminuser = true)
  public ReturnT<String> remove(int id) {
    int count = this.xxlJobInfoDao.pageListCount(0, 10, id, -1, null, null, null);
    if (count > 0)
      return new ReturnT(500, I18nUtil.getString("jobgroup_del_limit_0")); 
    List<XxlJobGroup> allList = this.xxlJobGroupDao.findAll();
    if (allList.size() == 1)
      return new ReturnT(500, I18nUtil.getString("jobgroup_del_limit_1")); 
    int ret = this.xxlJobGroupDao.remove(id);
    return (ret > 0) ? ReturnT.SUCCESS : ReturnT.FAIL;
  }
  
  @RequestMapping({"/loadById"})
  @ResponseBody
  @PermissionLimit(adminuser = true)
  public ReturnT<XxlJobGroup> loadById(int id) {
    XxlJobGroup jobGroup = this.xxlJobGroupDao.load(id);
    return (jobGroup != null) ? new ReturnT(jobGroup) : new ReturnT(500, null);
  }
}
